*******************************************************************
*                         VARIABLES
*******************************************************************
*            TEMPORARY HOLDERS, ASSIGNED AS NEEDED
*      c = character                n = numeric
*      s = string                  ok = logical
*
*                       ARRAY COUNTERS
*      x = head[] counter            r = run[] counter
*      p = pars[] counter            d = ddat[] counter
*      o = opt[] counter             f = fix[] counter
*
*                       CONFIG STRINGS
*   pstr = pars ".!*$sg"          ostr = opt "l#1f"
*   dstr = ddat "78901234"        fstr = fix "fanu"
*
*                      FILE I/O BUFFER 
*    buf = max buffer size        dbuf = .DIR buffer size
*   lbuf = LIST.LST buffer size   bbuf = .BBS buffer size
*                                 fbuf = .FIL buffer size
*
*                       FILE COUNTERS
*   dcnt = .DIR files              tcnt = total .DIR files
*   fcnt = .ZIP files                dd = deleted files by date
*
*                       FILE HANDLES  
*
*    lstf = LIST.LST               bbsf = current .BBS file 
*    dirf = current .DIR file      filf = current .FIL file 
*
*                        FILE NAMES
*   ffil = path\name of .FIL       bpat = to .BBS files and LIST.LST     
*   dfil = path\name of .DIR       dpat = to .DIR files    
*   bfil = name of .BBS file     bbsfil = path\name of .BBS file
*   lfil = path\name of LIST.LST
*   
*                     DESCRIPTION LINE
*    line = line read/written      size = file size substring
*    desc = description substring  name = name substring
*    path = CD path from LIST.LST  date = date substring
*     
*                         OTHER
*  kin,key = key input        
*        y = column in Main, = first pass indicator in Proc     
*      fil = holds FindFirst() and FindNext() data 
*******************************************************************
*                        PROCEDURES
*******************************************************************
*   BoxW: White box with optional shadow, <ANY KEY>
*   chek: Sets check mark in pBoxes
*   clrB: Clears pBoxes to blue
*   cBox: Displays count box
*   delN: Deletes repetitive name in description
*   EBox: Error messages and routine
*   End:  Summarizes file processsing stats for CD-ROM
*   Frmt: Formats description to .DIR format
*   dDsc: Locates and displays .DIR file description line
*   Lowr: Lower case and fix pick list
*   nLST: Use new LIST.LST
*   oBBS: Error routine for opening and reading first line of .BBS
*   Pars: Parses out unwanted characters
*   pBox: Pick boxes (pull-down menus)
*   Proc: Main processing routine for .BBS to .DIR
*******************************************************************

SET FORMAT TO fscr NOCLEAR
SET INTENSITY OFF
SET ESCAPE OFF

ok = .T.                                         &&  Initialize Variables
STORE " " TO bfil,kin,line,lfil,bpat,dpat,bbsfil,dfil
STORE 0 TO tcnt,dcnt,fcnt,dd,n
pstr = "xxxxxx"
dstr = "xxxxxxxx"
ostr = "xxxx"
fstr = "xxxx"

buf = fMaxLen()                                  && Allocate file buffers
IF buf > 6216
   STORE 1024 TO fbuf,bbuf,dbuf
   lbuf = buf - 3072
ELSE
   IF buf > 3072
      STORE 768 TO fbuf,bbuf,dbuf
      lbuf = buf - 2304
   ELSE
      IF buf > 1280
         STORE 256 TO fbuf,bbuf,dbuf
         lbuf = buf - 768
      ELSE
         STORE 0 TO fbuf,bbuf,dbuf
         lbuf = buf
      ENDIF
   ENDIF
ENDIF

DECLARE head[6]                                  && Fill menu arrays
head[1] = " File "
head[2] = " Parse "
head[3] = " Del-by-Date "
head[4] = " Fix text "
head[5] = " Options "
head[6] = " Help "

DECLARE run[6]
run[1] = " Continue      "
run[2] = " Non-Stop      "
run[3] = " Skip          "
run[4] = " New CD-ROM... "
run[5] = " New .DIR file "
run[6] = " Quit          "

DECLARE pars[7]
pars[1] = " ....... "
pars[2] = " !!!!!!! "
pars[3] = " ******* "
pars[4] = " $$$$$$$ "
pars[5] = " w space "           
pars[6] = " graphic "
pars[7] = " special "

DECLARE ddat[8]
ddat[1] = " 1987   "
ddat[2] = " 1988   "
ddat[3] = " 1989   "
ddat[4] = " 1990   "
ddat[5] = " 1991   "
ddat[6] = " 1992   "
ddat[7] = " 1993   "
ddat[8] = " 1994   "

DECLARE opt[5]
opt[1] = " Force to lower case "
opt[2] = " Do not change case  "
opt[3] = " Limit lines to...   "
opt[4] = " Create file list... "
opt[5] = " Create .FAR file    "
opt[6] = " Search keywords...  "
opt[7] = " Find old versions   "

DECLARE fix[5]
fix[1] =  " Cap first letter   "
fix[2] =  " Caps on names      "
fix[3] =  " Upper Case...      "
fix[4] =  " Del InterNet addr. "
fix[5] =  " Del Phone numbers  "

DECLARE upp[4]
upp[1] = " <asp> to <ASP>     "
upp[2] = " SHAREWARE and FREE "
upp[3] = " BBS,TBBS,RBBS,etc. "



SET COLOR TO B/B
@ 0,0 CLEAR
SET COLOR TO W/W
@ 0,0 CLEAR TO 0,79
@ 24,0 CLEAR TO 24,79
SET COLOR TO N/W
@ 0,10 SAY " Parse "
@ 0,17 SAY " Del-by-Date "
@ 0,30 SAY " Options "
SET COLOR TO W/N
@ 0,4 SAY " File "

DO BoxW WITH 7,21,15,58,"sa"                     && Title
@ 9,28 SAY "TBBS .DIR file creator"
@ 11,23 SAY "Copyright 1996, Darryl Kerkeslager"
@ 12,23 SAY "LocalNet BBS        (804) 598-2817"
SET COLOR TO W+/W
@ 8,31 SAY "dir Parser s1.0"
key = Inkey(8)
SET COLOR TO B/B
@ 7,21 CLEAR TO 16,59

DO WHILE .T.
   DO nLST
   FOPEN lstf (lfil) 10 lbuf                      && Open LIST.LST
   IF lstf < 0
      DO EBox WITH 2
      QUIT
   ENDIF

   bfil = FindFirst(fil,bpat + "*.bbs")            && Find first .BBS file
   IF Len(bfil) < 1
      DO EBox WITH 1
      QUIT
   ENDIF
   bbsfil = bpat + bfil
   FOPEN bbsf (bbsfil) 10 bbuf
   DO oBBS   
   DO dDsc   
   
   x = 1
   y = 4
   r = 1

   DO pBox WITH x

   SET COLOR TO B/B
   @ 22,0 GET kin
   
   DO WHILE .T. 
      READ
      DO CASE
         CASE LastKey() = 19                         && <Lt Arrow>
              r = 1
              p = 1
              d = 1
              o = 1
              SET COLOR TO N/W
              @ 0,y SAY head[x]
              DO clrB WITH x
              IF x = 1
                 x = 4
              ELSE
                 x = x - 1
              ENDIF
              DO CASE
                 CASE x = 1
                      y = 4
                 CASE x = 2
                      y = 10
                 CASE x = 3
                      y = 17
                 CASE x = 4
                      y = 30
              ENDCASE
              DO pBox WITH x
              DO chek WITH x
              SET COLOR TO W/N
              @ 0,y SAY head[x]
              
         CASE LastKey() = 4                        && <Rt Arrow>
              r = 1
              p = 1
              d = 1
              o = 1
              SET COLOR TO N/W
              @ 0,y SAY head[x]
              DO clrB WITH x
              IF x = 4 
                 x = 1
              ELSE
                 x = x + 1
              ENDIF
              DO CASE
                 CASE x = 1
                      y = 4
                 CASE x = 2
                      y = 10
                 CASE x = 3
                      y = 17
                 CASE x = 4
                      y = 30
              ENDCASE
              DO pBox WITH x
              DO chek WITH x
              SET COLOR TO W/N
              @ 0,y SAY head[x]
              
         CASE LastKey() = 5                        && <Up Arrow>
              SET COLOR TO N/W
              DO CASE
                 CASE x = 1
                      @ r+1,4 SAY run[r]
                      IF r = 1 
                         r = 5
                      ELSE
                         r = r - 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ r+1,4 SAY run[r]
                 
                 CASE x = 2
                      @ p+1,12 SAY pars[p]
                      IF p = 1 
                         p = 6
                      ELSE
                         p = p - 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ p+1,12 SAY pars[p]
              
                 CASE x = 3
                      @ d+1,19 SAY ddat[d]
                      IF d = 1 
                         d = 8
                      ELSE
                         d = d - 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ d+1,19 SAY ddat[d]
              
                 CASE x = 4
                      @ o+1,32 SAY opt[o]
                      IF o = 1 
                         o = 4
                      ELSE
                         o = o - 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ o+1,32 SAY opt[o]
           
              ENDCASE

         CASE LastKey() = 24                       && <Dn Arrow>
              SET COLOR TO N/W
              DO CASE
                 CASE x = 1
                      @ r+1,4 SAY run[r]
                      IF r = 5 
                         r = 1
                      ELSE
                         r = r + 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ r+1,4 SAY run[r]
                      
                 CASE x = 2
                      @ p+1,12 SAY pars[p]
                      IF p = 6 
                         p = 1
                      ELSE
                         p = p + 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ p+1,12 SAY pars[p]
                   
                 CASE x = 3
                      @ d+1,19 SAY ddat[d]
                      IF d = 8 
                         d = 1
                      ELSE
                         d = d + 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ d+1,19 SAY ddat[d]
                   
                 CASE x = 4
                      @ o+1,32 SAY opt[o]
                      IF o = 4 
                         o = 1
                      ELSE
                         o = o + 1
                      ENDIF
                      SET COLOR TO W+/N
                      @ o+1,32 SAY opt[o]
              ENDCASE

         CASE LastKey() = 13                        && <Enter>
              DO CASE
                 CASE x = 1
                      DO CASE
                         CASE r = 1
                              SET COLOR TO W/N
                              @ 2,4 SAY " Continue   "
                              
                              SET COLOR TO B/B      && Clear Description box
                              @ 9,30 CLEAR TO 13,70
                              DO cBox
                              fcnt = 0
                              DO Proc
                              SET COLOR TO B/B      && Clear cBox
                              @ 7,26 CLEAR TO 13,51
                              tcnt = tcnt + fcnt
                              dcnt = dcnt + 1
                              bfil = FindNext(fil)
                              IF Len(bfil) < 1
                                 DO End
                                 EXIT
                              ELSE
                                 bbsfil = bpat + bfil
                                 FOPEN bbsf (bbsfil) 10 bbuf
                                 DO oBBS
                                 DO dDsc   
                              ENDIF
                           
                              SET COLOR TO W+/N
                              @ 2,4 SAY " Continue   "
                           
                         CASE r = 2                 
                              SET COLOR TO W/N
                              @ 3,4 SAY " Non-Stop   "
                              SET COLOR TO B/B     && Clear Description box
                              @ 9,30 CLEAR TO 13,70
                              DO cBox
                              
                              DO WHILE .T.
                                 fcnt = 0
                                 SET COLOR TO W/W
                                 @ 10,37 CLEAR TO 10,49
                                 @ 11,35 CLEAR TO 11,39
                                 DO Proc
                                 tcnt = tcnt + fcnt
                                 dcnt = dcnt + 1
                                 bfil = FindNext(fil)
                                 IF Len(bfil) < 1
                                    SET COLOR TO B/B      && Clear cBox
                                    @ 7,26 CLEAR TO 13,51
                                    DO End
                                    ok = .F.
                                    EXIT
                                 ELSE
                                    bbsfil = bpat + bfil
                                    FOPEN bbsf (bbsfil) 10 bbuf
                                    DO oBBS   
                                 ENDIF
                              ENDDO
                              IF .NOT. ok
                                 ok = .T.
                                 EXIT
                              ENDIF

                              SET COLOR TO W+/N
                              @ 3,4 SAY " Non-Stop   "
                           
                         CASE r = 3  
                              SET COLOR TO W/N
                              @ 4,4 SAY " Skip       "
                           
                              SET COLOR TO B/B      && Clear Description box
                              @ 9,30 CLEAR TO 13,70
                              FCLOSE bbsf
                              bfil = FindNext(fil)
                              IF Len(bfil) < 1
                                 DO End
                                 EXIT
                              ELSE
                                 bbsfil = bpat + bfil
                                 FOPEN bbsf (bbsfil) 10 bbuf
                                 DO oBBS
                                 DO dDsc   
                              ENDIF
                           
                              SET COLOR TO W+/N
                              @ 4,4 SAY " Skip       "
                      
                         CASE r = 4
                              SET COLOR TO W/N
                              @ 5,4 SAY " New CD-ROM "
                              
                              SET COLOR TO B/B      && Clear Description box
                              @ 9,30 CLEAR TO 13,70
                              FCLOSE
                              EXIT
                              
                         CASE r = 5
                              QUIT
                      ENDCASE
                 
                 CASE x = 2
                      DO CASE 
                         CASE p = 1
                              c = "."     
                         CASE p = 2     
                              c = "!"     
                         CASE p = 3     
                              c = "*"     
                         CASE p = 4
                              c = "$"     
                         CASE p = 5
                              c = "s"     
                         CASE p = 6
                              c = "g"     
                      ENDCASE   
                      IF c $ pstr
                         pstr = Stuff(pstr,p,1,"x")
                         SET COLOR TO W/W
                         @ p+1,11 SAY " "
                      ELSE
                         pstr = Stuff(pstr,p,1,c)
                         SET COLOR TO W+/W
                         @ p+1,11 SAY ""
                      ENDIF
   
                 CASE x = 3
                      DO CASE 
                         CASE d = 1
                              c = "7"     
                         CASE d = 2     
                              c = "8"     
                         CASE d = 3     
                              c = "9"     
                         CASE d = 4
                              c = "0"     
                         CASE d = 5
                              c = "1"     
                         CASE d = 6
                              c = "2"     
                         CASE d = 7
                              c = "3"     
                         CASE d = 8
                              c = "4"     
                      ENDCASE   
                      IF c $ dstr
                         dstr = Stuff(dstr,d,1,"x")
                         SET COLOR TO W/W
                         @ d+1,18 SAY " "
                      ELSE
                         dstr = Stuff(dstr,d,1,c)
                         SET COLOR TO W+/W
                         @ d+1,18 SAY ""
                      ENDIF
              
                 CASE x = 4
                      f = 1
                      DO CASE 
                         CASE o = 1
                              f = 1
                              DO Lowr
                         CASE o = 2                   && "Do not change case"
                              IF "l" $ ostr
                                 ostr = Stuff(ostr,1,1,"u")
                                 fstr = Stuff(fstr,1,4,"xxxx")
                                 SET COLOR TO W+/W
                                 @ 3,31 SAY ""
                                 SET COLOR TO W/W
                                 @ 2,31 SAY " "
                              ELSE
                                 o = 2
                                 f = 1
                                 DO Lowr
                              ENDIF
                         CASE o = 3                   && "Limit lines/listing"
                              IF "#" $ ostr
                                 ostr = Stuff(ostr,2,1,"x")
                                 SET COLOR TO W/W
                                 @ 4,31 SAY " "
                              ELSE
                                 SET COLOR TO W/N
                                 @ 4,32 SAY " Limit lines to...   "
                                 DO BoxW WITH 15,5,18,35,"s"
                                 @ 16,7 SAY "Enter the maximum number of"
                                 @ 17,7 SAY "lines per listing.   [ ]"
                                 SET COLOR TO W+/W
                                 c = 0
                                 DO WHILE c = 0
                                    @ 17,29 GET c PICTURE "@Z 9"
                                    READ
                                 ENDDO
                                 c = LTrim(Str(c))
                                 ostr = Stuff(ostr,2,1,"#")
                                 ostr = Stuff(ostr,3,1,c)
                                 key = InKey(1)
                                 SET COLOR TO B/B
                                 @ 15,5 CLEAR TO 19,36
                                 SET COLOR TO W+/N
                                 @ 4,32 SAY " Limit lines to...   "
                                 SET COLOR TO W+/W
                                 @ 4,31 SAY ""
                              ENDIF
                         CASE o = 4
                              IF "f" $ ostr
                                 ostr = Stuff(ostr,4,1,"x")
                                 SET COLOR TO W/W
                                 @ 5,31 SAY " "
                              ELSE
                                 ostr = Stuff(ostr,4,1,"f")
                                 SET COLOR TO W+/W
                                 @ 5,31 SAY ""
                              ENDIF
                      ENDCASE   
              ENDCASE
         OTHERWISE
             LOOP
      ENDCASE
   ENDDO
ENDDO
QUIT


**************************************************
PROCEDURE pBox
PARAMETERS p

DO CASE
   CASE p = 1                                    && Run
        DO BoxW WITH 1,3,7,16,"s" 
        @ 3,4 SAY " Non-Stop   "
        @ 4,4 SAY " Skip       "
        @ 5,4 SAY " New CD-ROM "
        @ 6,4 SAY " Quit       "
        SET COLOR TO W+/N
        @ 2,4 SAY " Continue   "
   
   CASE p = 2                                    && Parse
        DO BoxW WITH 1,9,8,19,"s"      
        @ 3,12 SAY " !!!!! "
        @ 4,12 SAY " ***** "
        @ 5,12 SAY " $$$$$ "
        @ 6,12 SAY " space "           
        @ 7,12 SAY " graph "
        SET COLOR TO W+/N
        @ 2,12 SAY " ..... "
   
   CASE p = 3                                    && Del-by-Date
        DO BoxW WITH 1,16,10,27,"s"
        @ 3,19 SAY " 1988   "
        @ 4,19 SAY " 1989   "
        @ 5,19 SAY " 1990   "
        @ 6,19 SAY " 1991   "
        @ 7,19 SAY " 1992   "
        @ 8,19 SAY " 1993   "
        @ 9,19 SAY " 1994   "
        SET COLOR TO W+/N
        @ 2,19 SAY " 1987   "
   
   CASE p = 4                                    && Options
        DO BoxW WITH 1,29,6,53,"s"      
        @ 3,32 SAY " Do not change case  "
        @ 4,32 SAY " Limit lines to...   "
        @ 5,32 SAY " Create file list... "
        SET COLOR TO W+/N
        @ 2,32 SAY " lower case & fix... "

   CASE p = 5                                    && Fix
        DO BoxW WITH 2,54,7,77,"s"      
        @ 4,57 SAY " <asp> to <ASP>     "
        @ 5,57 SAY " Caps on names      "
        @ 6,57 SAY " SHAREWARE and FREE "
        SET COLOR TO W+/N
        @ 3,57 SAY " Cap first letter   "

ENDCASE
RETURN


**************************************************
PROCEDURE chek
PARAMETERS n

SET COLOR TO W+/W
DO CASE
   CASE n = 1
        RETURN
   CASE n = 2
        IF "." $ pstr
           @ 2,11 SAY ""
        ENDIF
        IF "!" $ pstr
           @ 3,11 SAY ""
        ENDIF
        IF "*" $ pstr
           @ 4,11 SAY ""
        ENDIF
        IF "$" $ pstr
           @ 5,11 SAY ""
        ENDIF
        IF "s" $ pstr
           @ 6,11 SAY ""
        ENDIF
        IF "g" $ pstr
           @ 7,11 SAY ""
        ENDIF

   CASE n = 3
        IF "7" $ dstr
           @ 2,18 SAY ""
        ENDIF
        IF "8" $ dstr
           @ 3,18 SAY ""
        ENDIF
        IF "9" $ dstr
           @ 4,18 SAY ""
        ENDIF
        IF "0" $ dstr
           @ 5,18 SAY ""
        ENDIF
        IF "1" $ dstr
           @ 6,18 SAY ""
        ENDIF
        IF "2" $ dstr
           @ 7,18 SAY ""
        ENDIF
        IF "3" $ dstr
           @ 8,18 SAY ""
        ENDIF
        IF "4" $ dstr
           @ 9,18 SAY ""
        ENDIF

   CASE n = 4
        IF "l" $ ostr
           @ 2,31 SAY ""
        ELSE 
           @ 3,31 SAY ""
        ENDIF
        IF "#" $ ostr
           @ 4,31 SAY ""
        ENDIF
        IF "f" $ ostr
           @ 5,31 SAY ""
        ENDIF
   CASE n = 5
        IF "f" $ fstr
           @ 3,56 SAY ""
        ENDIF
        IF "a" $ fstr
           @ 4,56 SAY ""
        ENDIF
        IF "n" $ fstr
           @ 5,56 SAY ""
        ENDIF
        IF "u" $ fstr
           @ 6,56 SAY ""
        ENDIF
ENDCASE
RETURN

**************************************************
PROCEDURE BoxW
PARAMETERS x,y,n,c,s

SET COLOR TO W/W
@ x,y CLEAR TO n,c
IF "s" $ s
  SET COLOR TO N/N
  @ n+1,y+1 CLEAR TO n+1,c
  @ x+1,c+1 CLEAR TO n+1,c+1
ENDIF
SET COLOR TO N/W
IF "+" $ s
  SET COLOR TO W+/W
ENDIF
@ x,y SAY ""
@ x,y+1 TO x,c
@ x,c SAY ""
@ x+1,y TO n,y
@ n,y SAY ""
IF "a" $ s
  SET COLOR TO W+/W
  @ n-1,Ceiling((c-y-11)/2)+y SAY "< ANY KEY >"
ENDIF                           
SET COLOR TO N/W
@ x+1,c TO n,c              
@ n,y+1 TO n,c               
@ n,c SAY ""                
RETURN


**************************************************
PROCEDURE clrB
PARAMETERS n

SET COLOR TO B/B
DO CASE
   CASE n = 1
        @ 1,3 CLEAR TO 8,17
   CASE n = 2
        @ 1,9 CLEAR TO 9,20
   CASE n = 3
        @ 1,16 CLEAR TO 11,28
   CASE n = 4
        @ 1,29 CLEAR TO 7,54
ENDCASE
RETURN


**************************************************
PROCEDURE nLST

bpat = "C:\CDROM                      "
dpat = "C:\CDROM                      "
DO BoxW WITH 8,20,13,55,"s"
@ 9,22 SAY "Path to LIST.LST and .BBS files:" 
@ 11,22 SAY "Target path for .DIR files:" 
SET COLOR TO W+/W
@ 10,22 SAY "[                              ]"
@ 12,22 SAY "[                              ]"
SET COLOR TO N/W
@ 10,23 GET bpat PICTURE "@K!"
@ 12,23 GET dpat PICTURE "@K!" 
READ
key = InKey(3)
SET COLOR TO B/B
@ 8,20 CLEAR TO 14,56
bpat = Rtrim(bpat)  
dpat = RTrim(dpat)
n = Len(bpat)
IF SubStr(bpat,n,1) # "\"
   bpat = bpat + "\"
ENDIF
n = Len(dpat)
IF SubStr(dpat,n,1) # "\"
   dpat = dpat + "\"
ENDIF

lfil = bpat + "LIST.LST" 
RETURN


**************************************************
PROCEDURE oBBS

IF bbsf < 0
   DO EBox WITH 3
   QUIT
ENDIF

FLREAD bbsf n line 

IF n <= 0 
   DO EBox WITH 4
   QUIT
ENDIF

RETURN


**************************************************
PROCEDURE dDsc

IF ".ZIP" $ line .OR. ".GIF" $ line .OR. ".TXT" $ line
   DO BoxW WITH 9,30,13,65,"sa"
   @ 10,32 SAY ".DIR Description line not found."
   key = InKey(40)
   SET COLOR TO B/B
   @ 9,30 CLEAR TO 14,66
ELSE
   line = RTrim(CRTrim(line))
   n = Len(line)
   IF n > 40 
      line = SubStr(line,1,40)
   ENDIF
   n = Max(n,22)
   DO BoxW WITH 9,30,12,n+34,"s"
   @ 10,32 SAY ".DIR file description:"
   @ 11,32 SAY line
ENDIF

RETURN

**************************************************
PROCEDURE cBox

DO BoxW WITH 7,26,12,50,"s"
@ 10,28 SAY "Creating "
@ 11,28 SAY "Files: "
SET COLOR TO W+/W
@ 8,31 SAY "dir Parser s1.0"

RETURN
         
**************************************************
PROCEDURE End

DO BoxW WITH 7,23,15,56,"s"
@ 8,25 SAY "Finished creating .DIR files."
@ 10,25 SAY ".DIR files created: "
@ 10,45 SAY LTrim(Str(dcnt))
@ 11,25 SAY "Files processed: "
@ 11,42 SAY LTrim(Str(tcnt))
@ 12,25 SAY "Files eliminated by date: "
@ 12,51 SAY LTrim(Str(dd))
SET COLOR TO W+/W
@ 14,34 SAY "< Q to QUIT >"
key = InKey(30)
IF key = 81 .OR. key = 113
   QUIT
ENDIF
SET COLOR TO B/B
@ 7,23 CLEAR TO 16,57
RETURN


**************************************************
PROCEDURE Lowr

SET COLOR TO W/N
@ 2,32 SAY " lower case & fix... "
DO pBox WITH 5
DO chek WITH 5
SET COLOR TO B/B
@ 22,0 GET kin
DO WHILE .T.
   READ
   DO CASE
      CASE LastKey() = 24         && <Dn Arrow>
           SET COLOR TO N/W
           @ f+2,57 SAY fix[f]
           IF f = 4 
              f = 1
           ELSE
              f = f + 1
           ENDIF
           SET COLOR TO W+/N
           @ f+2,57 SAY fix[f]
           
      CASE LastKey() = 5           && <Up Arrow>
           SET COLOR TO N/W
           @ f+2,57 SAY fix[f]
           IF f = 1 
              f = 4
           ELSE
              f = f - 1
           ENDIF
           SET COLOR TO W+/N
           @ f+2,57 SAY fix[f]
           
      CASE LastKey() = 13          && <Enter>
           DO CASE 
              CASE f = 1
                   c = "f"     
              CASE f = 2     
                   c = "a"     
              CASE f = 3     
                   c = "n"     
              CASE f = 4
                   c = "u"     
           ENDCASE   
           IF c $ fstr
              fstr = Stuff(fstr,f,1,"x")
              SET COLOR TO W/W
              @ f+2,56 SAY " "
           ELSE
              fstr = Stuff(fstr,f,1,c)
              SET COLOR TO W+/W
              @ f+2,56 SAY ""
           ENDIF
           
      CASE LastKey() = 27          && <Esc>
           SET COLOR TO B/B
           @ 2,54 CLEAR TO 8,78
           SET COLOR TO N/N
           @ 1,54 CLEAR TO 7,54
           EXIT
      OTHERWISE
           LOOP
   ENDCASE
ENDDO
ostr = Stuff(ostr,1,1,"l")
SET COLOR TO W+/N
@ 2,32 SAY " lower case & fix... "
SET COLOR TO W+/W
@ 2,31 SAY ""
SET COLOR TO W/W
@ 3,31 SAY " "
RETURN


**************************************************
PROCEDURE Proc
PRIVATE y

y = 1

DO WHILE .T.                                     
   FLREAD bbsf n line                        && Check if good line  
   IF n <= 0                                 
      EXIT                                
   ENDIF
   IF .NOT. (".ZIP" $ line .OR. ".GIF" $ line .OR. ".TXT" $ line)
      LOOP
   ENDIF
   
   line = RTrim(CRTrim(line))                   && Trim fat from line
   n = At(" ",line)
   
   name = SubStr(line,1,n-1)                    && Get file name (name)
   line = LTrim(SubStr(line,n))
   
   n = At("-",line)                          && Check for valid date format 
   IF n = 0
      DO EBox WITH 7
      QUIT
   ENDIF
   n = n + 3                                
   IF SubStr(line,n,1) # "-"
      DO EBox WITH 7
      QUIT
   ENDIF
                       
   fcnt = fcnt + 1
   SET COLOR TO N/W
   @ 11,35 SAY LTrim(Str(fcnt))
   
   n = n + 2
   s = SubStr(line,1,n)                         && file size and date
   desc = LTrim(SubStr(line,n+1))               && Get description
   date = SubStr(line,n-7,8)                    && Get file date
   size = RTrim(SubStr(line,1,n-8))             && Get file size
   
   IF dstr # "xxxxxxxx"                        && If Del-by-Date
      s = Val(SubStr(date,7,2))
      IF "7" $ dstr .AND. s <= 87
        dd = dd + 1
        LOOP
      ENDIF
      n = 2
      DO WHILE n <= 8
         c = SubStr(dstr,n,1)
         IF c = "x"
            n = n + 1
            LOOP
         ELSE
            c = Val(c)
         ENDIF
         IF n < 4
            c = c + 80
         ELSE
            c = c + 90
         ENDIF
         IF s = c
            dd = dd + 1
            ok = .F.
            EXIT
         ENDIF
         n = n + 1
      ENDDO
      IF .NOT. ok
         ok = .T.
         LOOP
      ENDIF
   ENDIF
   
   FSEEK lstf n 0 0                           && Find name in LIST.LST
   FLFIND lstf n name
   IF n <= 0
      LOOP
   ENDIF
   
   FLREAD lstf n path                         && Get path from LIST.LST
   path = CRTrim(path)                           
   
   IF pstr # "xxxxxx"                          && IF Parse description
      IF "." $ pstr
         DO Pars WITH 46
      ENDIF
      IF "!" $ pstr
         DO Pars WITH 33
      ENDIF
      IF "*" $ pstr
         DO Pars WITH 42
      ENDIF
      IF "$" $ pstr
         DO Pars WITH 36
      ENDIF
      IF "g" $ pstr
         n = 176
         DO WHILE n <= 223
            DO Pars WITH n
            n = n + 1
         ENDDO
      ENDIF
      IF "s" $ pstr
         DO Pars WITH 32
      ENDIF
   ENDIF
   
   s = SubStr(desc,1,12)
   DO delN WITH ".txt"
   DO delN WITH ".TXT"
   DO delN WITH ".gif"
   DO delN WITH ".GIF"
   DO delN WITH ".exe"
   DO delN WITH ".EXE"
   
   IF "#" $ ostr                                 && IF Limit lines/listing
      n = Val(SubStr(ostr,3,1))*45
      IF Len(desc) > n
         c = SubStr(desc,n+1,1)
         DO WHILE c # " "          
            n = n - 1
            c = SubStr(desc,n+1,1)
         ENDDO
         desc = LTrim(SubStr(desc,1,n))
      ENDIF
   ENDIF

   IF "l" $ ostr                                 && IF Force to lower
      desc = Lower(desc)                          
      
      IF "f" $ fstr                              && IF Fix Cap First
         desc = CapFirst(desc)     
      ENDIF
      
      IF "a" $ fstr                              && IF Fix <ASP>
         IF "<asp>" $ desc
            n = At("<asp>",desc)
            desc = Stuff(desc,n,5,"<ASP>")
         ELSE
            IF "(asp)" $ desc 
               n = At("(asp)",desc)
               desc = Stuff(desc,n,5,"<ASP>")
            ENDIF
         ENDIF
      ENDIF
   
      IF "n" $ fstr                              && IF Fix names
        IF " by " $ desc
           n = At(" by ",desc) + 4
           s = Upper(SubStr(desc,n,1))
           desc = Stuff(desc,n,1,s)
           DO WHILE SubStr(desc,n,1) # " " .AND. n < Len(desc)
              n = n + 1
           ENDDO
           IF n < Len(desc)
              n = n + 1
              s = Upper(SubStr(desc,n,1))
              desc = Stuff(desc,n,1,s)
           ENDIF
        ENDIF
      ENDIF
      
      IF "u" $ fstr                              && IF SHAREWARE and FREE
         IF "free" $ desc
            n = At("free",desc)
            desc = Stuff(desc,n,4,"FREE")
         ENDIF
         IF "shareware" $ desc
            n = At("shareware",desc)
            desc = Stuff(desc,n,9,"SHAREWARE")
         ENDIF
      ENDIF
   ENDIF
   
   IF "f" $ ostr                                 && IF Create listing file
      IF y = 1
         ffil = SubStr(bfil,1,Len(bfil)-3) + "FIL"  
         ffil = bpat + ffil
         FCREATE filf (ffil) 13 0 fbuf
         
         IF filf < 0
            DO EBox WITH 5
            QUIT
         ENDIF
      ENDIF
      n = 13 - Len(name)
      s = Replicate(Chr(32),n)

      line =  name + s + date + " " + desc + Chr(13) + Chr(10)
      FLWRITE filf n line
      IF n = 0
         FCLOSE
         QUIT
      ENDIF
   ENDIF
   IF y = 1
      dfil = SubStr(bfil,1,Len(bfil)-3) + "DIR"          && Create .DIR file 
      SET COLOR TO N/W
      @ 10,37 SAY dfil
      dfil = dpat + dfil
      FCREATE dirf (dfil) 13 0 dbuf                   
      IF dirf < 0
         DO EBox WITH 6
         QUIT
      ENDIF
   ENDIF

   n = 1                                      && Write formatted listing
   ok = .F.                                   && to .DIR file
   DO WHILE .NOT. ok
      DO Frmt WITH ok,s
      IF n = 1
         line = path+" "+size+" "+date+" "+name+" "+s+Chr(13)+Chr(10)
      ELSE
         line = "!>"+s+Chr(13)+Chr(10)
      ENDIF   
      n = n + 1
      FLWRITE dirf c line
      IF c = 0
         FCLOSE
         QUIT
      ENDIF
   ENDDO
   y = 0
   ok = .T.
ENDDO
IF "f" $ ostr
   FCLOSE filf
ENDIF
FCLOSE bbsf
FCLOSE dirf
RETURN

**************************************************
PROCEDURE delN   
PARAMETERS c

IF c $ s 
   n = At(s,desc) + 4
   desc = SubStr(desc,n)
ENDIF
RETURN

**************************************************
PROCEDURE Pars
PARAMETERS c

PRIVATE n

DO WHILE ok
   IF Chr(c)+Chr(c) $ desc
      s = At(Chr(c)+Chr(c),desc)
      n = s 
      DO WHILE SubStr(desc,n,1) = Chr(c) .AND. n < Len(desc)
         n = n + 1                                           
      ENDDO
      IF s = 1
         desc = SubStr(desc,n)
      ELSE
         desc = SubStr(desc,1,s-1) + " " + SubStr(desc,n)
      ENDIF
   ELSE
      ok = .F.
   ENDIF
ENDDO
ok = .T.
RETURN


**************************************************
PROCEDURE Frmt
PARAMETERS ok,s
PRIVATE n   

IF Len(desc) < 46
      ok = .T.
      s = desc
      RETURN
   ELSE
      n = 45
      DO WHILE SubStr(desc,n,1) # " "
         n = n - 1
      ENDDO
      s = RTrim(SubStr(desc,1,n-1))
      desc = LTRim(SubStr(desc,n))
ENDIF
RETURN


**************************************************
PROCEDURE EBox 
PARAMETERS n

DO BoxW WITH 9,28,13,59,"sa"
PRIVATE s

DO CASE
   CASE n = 1 
        s = " No valid .BBS files found. "
   CASE n = 2
        s = "   Error opening LIST.LST   "
   CASE n = 3     
        s = "  Error opening .BBS file.  "
   CASE n = 4                              
        s = "  Error reading .BBS file.  "
   CASE n = 5         
        s = "Error creating listing file."
   CASE n = 6              
        s = "  Error creating .DIR file. "
   CASE n = 7   
        s = "Invalid date format in .BBS."
ENDCASE

@ 10,30 SAY s
key = InKey(40)

RETURN



